==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/FloatingToolbarFragmentConfigurationPanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/fragment_configuration/FloatingToolbarFragmentConfigurationPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './field_types/ColorPaletteField.es', './field_types/CheckboxField.es', './field_types/ItemSelectorField.es', './field_types/SelectField.es', './field_types/TextField.es', './FloatingToolbarFragmentConfigurationPanelDelegateTemplate.soy', '../../../actions/updateEditableValue.es', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorUpdateUtils.es', './FloatingToolbarFragmentConfigurationPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarFragmentConfigurationPanel = exports.ConnectedFloatingToolbarFragmentConfigurationPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./field_types/ColorPaletteField.es");

  require("./field_types/CheckboxField.es");

  require("./field_types/ItemSelectorField.es");

  require("./field_types/SelectField.es");

  require("./field_types/TextField.es");

  require("./FloatingToolbarFragmentConfigurationPanelDelegateTemplate.soy");

  var _updateEditableValue = require("../../../actions/updateEditableValue.es");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorUpdateUtils = require("../../../utils/FragmentsEditorUpdateUtils.es");

  var _FloatingToolbarFragmentConfigurationPanel = _interopRequireDefault(require("./FloatingToolbarFragmentConfigurationPanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarFragmentConfigurationPanel
   */
  var FloatingToolbarFragmentConfigurationPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarFragmentConfigurationPanel, _Component);

    function FloatingToolbarFragmentConfigurationPanel() {
      _classCallCheck(this, FloatingToolbarFragmentConfigurationPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarFragmentConfigurationPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarFragmentConfigurationPanel, [{
      key: "_handleChangeConfiguration",

      /**
       * Handles Configuration change
       * @private
       * @review
       */
      value: function _handleChangeConfiguration(event) {
        var _this = this;

        var fieldName = event.name,
            fieldValue = event.value;
        var nextConfigurationValues = (0, _FragmentsEditorUpdateUtils.setIn)(this.item.configurationValues, [fieldName], fieldValue);
        Object.keys(nextConfigurationValues).forEach(function (key) {
          if (nextConfigurationValues[key] === _this.item.defaultConfigurationValues[key]) {
            nextConfigurationValues = (0, _FragmentsEditorUpdateUtils.deleteIn)(nextConfigurationValues, [key]);
          }
        });

        this._sendConfiguration(nextConfigurationValues);
      }
      /**
       * Handles Restore button click
       * @private
       * @review
       */

    }, {
      key: "_handleRestoreButtonClick",
      value: function _handleRestoreButtonClick() {
        this._sendConfiguration({});
      }
      /**
       * Update editableValues with new configuration
       * @param {object} configurationValues
       * @private
       * @review
       */

    }, {
      key: "_sendConfiguration",
      value: function _sendConfiguration(configurationValues) {
        this.store.dispatch((0, _updateEditableValue.updateFragmentConfigurationAction)(this.item.fragmentEntryLinkId, configurationValues));
      }
    }]);

    return FloatingToolbarFragmentConfigurationPanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarFragmentConfigurationPanel = FloatingToolbarFragmentConfigurationPanel;
  FloatingToolbarFragmentConfigurationPanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarLinkPanel
     * @review
     * @type {object}
     */
    item: _metalState.Config.object().value(null),

    /**
     * @default undefined
     * @memberof FloatingToolbarFragmentConfigurationPanel
     * @review
     * @type {!string}
     */
    itemId: _metalState.Config.string().required()
  };
  var ConnectedFloatingToolbarFragmentConfigurationPanel = (0, _ConnectedComponent.getConnectedComponent)(FloatingToolbarFragmentConfigurationPanel, ['defaultSegmentsExperienceId', 'segmentsExperienceId', 'spritemap']);
  exports.ConnectedFloatingToolbarFragmentConfigurationPanel = ConnectedFloatingToolbarFragmentConfigurationPanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarFragmentConfigurationPanel, _FloatingToolbarFragmentConfigurationPanel["default"]);

  var _default = ConnectedFloatingToolbarFragmentConfigurationPanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarFragmentConfigurationPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarFragmentConfigurationPanel.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.126.jar: META-INF/resources/js/components/floating_toolbar/fragment_configuration/FloatingToolbarFragmentConfigurationPanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.126/js/components/floating_toolbar/fragment_configuration/FloatingToolbarFragmentConfigurationPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', 'frontend-js-metal-web$metal-state', './field_types/ColorPaletteField.es', './field_types/CheckboxField.es', './field_types/ItemSelectorField.es', './field_types/SelectField.es', './field_types/TextField.es', './FloatingToolbarFragmentConfigurationPanelDelegateTemplate.soy', '../../../actions/updateEditableValue.es', '../../../store/ConnectedComponent.es', '../../../utils/FragmentsEditorUpdateUtils.es', './FloatingToolbarFragmentConfigurationPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarFragmentConfigurationPanel = exports.ConnectedFloatingToolbarFragmentConfigurationPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireDefault(require("frontend-js-metal-web$metal-soy"));

  var _metalState = require("frontend-js-metal-web$metal-state");

  require("./field_types/ColorPaletteField.es");

  require("./field_types/CheckboxField.es");

  require("./field_types/ItemSelectorField.es");

  require("./field_types/SelectField.es");

  require("./field_types/TextField.es");

  require("./FloatingToolbarFragmentConfigurationPanelDelegateTemplate.soy");

  var _updateEditableValue = require("../../../actions/updateEditableValue.es");

  var _ConnectedComponent = require("../../../store/ConnectedComponent.es");

  var _FragmentsEditorUpdateUtils = require("../../../utils/FragmentsEditorUpdateUtils.es");

  var _FloatingToolbarFragmentConfigurationPanel = _interopRequireDefault(require("./FloatingToolbarFragmentConfigurationPanel.soy"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarFragmentConfigurationPanel
   */
  var FloatingToolbarFragmentConfigurationPanel = /*#__PURE__*/function (_Component) {
    _inherits(FloatingToolbarFragmentConfigurationPanel, _Component);

    function FloatingToolbarFragmentConfigurationPanel() {
      _classCallCheck(this, FloatingToolbarFragmentConfigurationPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarFragmentConfigurationPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarFragmentConfigurationPanel, [{
      key: "_handleChangeConfiguration",

      /**
       * Handles Configuration change
       * @private
       * @review
       */
      value: function _handleChangeConfiguration(event) {
        var _this = this;

        var fieldName = event.name,
            fieldValue = event.value;
        var nextConfigurationValues = (0, _FragmentsEditorUpdateUtils.setIn)(this.item.configurationValues, [fieldName], fieldValue);
        Object.keys(nextConfigurationValues).forEach(function (key) {
          if (nextConfigurationValues[key] === _this.item.defaultConfigurationValues[key]) {
            nextConfigurationValues = (0, _FragmentsEditorUpdateUtils.deleteIn)(nextConfigurationValues, [key]);
          }
        });

        this._sendConfiguration(nextConfigurationValues);
      }
      /**
       * Handles Restore button click
       * @private
       * @review
       */

    }, {
      key: "_handleRestoreButtonClick",
      value: function _handleRestoreButtonClick() {
        this._sendConfiguration({});
      }
      /**
       * Update editableValues with new configuration
       * @param {object} configurationValues
       * @private
       * @review
       */

    }, {
      key: "_sendConfiguration",
      value: function _sendConfiguration(configurationValues) {
        this.store.dispatch((0, _updateEditableValue.updateFragmentConfigurationAction)(this.item.fragmentEntryLinkId, configurationValues));
      }
    }]);

    return FloatingToolbarFragmentConfigurationPanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarFragmentConfigurationPanel = FloatingToolbarFragmentConfigurationPanel;
  FloatingToolbarFragmentConfigurationPanel.STATE = {
    /**
     * @default undefined
     * @memberof FloatingToolbarLinkPanel
     * @review
     * @type {object}
     */
    item: _metalState.Config.object().value(null),

    /**
     * @default undefined
     * @memberof FloatingToolbarFragmentConfigurationPanel
     * @review
     * @type {!string}
     */
    itemId: _metalState.Config.string().required()
  };
  var ConnectedFloatingToolbarFragmentConfigurationPanel = (0, _ConnectedComponent.getConnectedComponent)(FloatingToolbarFragmentConfigurationPanel, ['defaultSegmentsExperienceId', 'segmentsExperienceId', 'spritemap']);
  exports.ConnectedFloatingToolbarFragmentConfigurationPanel = ConnectedFloatingToolbarFragmentConfigurationPanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarFragmentConfigurationPanel, _FloatingToolbarFragmentConfigurationPanel["default"]);

  var _default = ConnectedFloatingToolbarFragmentConfigurationPanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarFragmentConfigurationPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarFragmentConfigurationPanel.es.js.map
